package org.ow2.orchestra.axis;

import java.util.ArrayList;
import java.util.List;

import javax.wsdl.Service;
import javax.xml.namespace.QName;

import org.jbpm.env.Environment;
import org.ow2.orchestra.execution.BpelProcess;
import org.ow2.orchestra.execution.services.OperationKey;
import org.ow2.orchestra.execution.services.Receiver;
import org.ow2.orchestra.execution.services.impl.PublisherImpl;
import org.ow2.orchestra.execution.services.itf.Repository;
import org.ow2.orchestra.wsdl.WsdlsInfos;

/**
 * AxisServicePublisher.java. Implementation of the service publisher with axis.
 * 
 * @author Charles Souillard
 * 
 * Created on : Jun 26, 2007
 */
public class AxisPublisher extends PublisherImpl {

  public void publishServices(BpelProcess bpelProcess, Environment environment) {
    super.publishServices(bpelProcess, environment);
    AxisDeployer axisDeployer = new AxisDeployer(bpelProcess);
    List<Service> services = getServices(bpelProcess);
    if (services != null) {
      axisDeployer.deploy(services);
    }
  }

  public void unpublishServices(BpelProcess bpelProcess, Environment environment) {
    QName processQName = bpelProcess.getQName();
    AxisDeployer axisDeployer = new AxisDeployer(bpelProcess);
    List<Service> services = getServices(bpelProcess);
    if (services != null) {
      axisDeployer.undeploy(services);
    }
    super.unpublishServices(bpelProcess, environment);
  }

  private List<Service> getServices(BpelProcess bpelProcess) {
    QName processQName = bpelProcess.getQName();

    Repository repository = Environment.getCurrent().get(Repository.class);
    List<Receiver> receivers = repository.getReceivers(processQName);

    WsdlsInfos wsdlInfos = bpelProcess.getWsdlInfos();
    List<Service> services = null;
    for (Receiver receiver : receivers) {
      OperationKey operationKey = receiver.getOperationKey();
      QName portTypeQName = operationKey.getPortTypeQName();
      List<Service> portTypeServices = wsdlInfos
          .getServicesOfPortType(portTypeQName);
      if (portTypeServices != null) {
        if (services == null) {
          services = new ArrayList<Service>();
        }
        for (Service service : portTypeServices) {
          if (!services.contains(service)) {
            services.add(service);
          }
        }
      }
    }
    return services;
  }

  @Override
  public void republishServices(BpelProcess bpelProcess, Environment environment) {
    QName processQName = bpelProcess.getQName();
    AxisDeployer axisDeployer = new AxisDeployer(bpelProcess);
    List<Service> services = getServices(bpelProcess);
    if (services != null) {
      axisDeployer.redeployServices(services);
    }
  }
}
