package org.ow2.orchestra.env;

import java.util.HashSet;
import java.util.Set;

import javax.xml.namespace.QName;
import javax.xml.parsers.DocumentBuilderFactory;

import org.jbpm.env.EnvironmentFactory;
import org.jbpm.env.xml.EnvironmentParser;
import org.jbpm.wire.xml.WireParser;
import org.jbpm.xml.Bindings;
import org.jbpm.xml.Parse;
import org.ow2.orchestra.env.binding.HibernateBpelPersistenceServiceBinding;
import org.ow2.orchestra.env.binding.ImplementationBinding;

public class BpelEnvironmentParser extends EnvironmentParser {

  private static EnvironmentParser instance;

  private static final String ENVIRONMENT_NS = "http://orchestra.ow2.org/environment";

  public static synchronized EnvironmentParser getInstance() {
    if (instance == null) {
      instance = new BpelEnvironmentParser();
      // Get bindings
      Bindings bindings = instance.getBlockWireXmlParser().getBindings();
      Set<QName> qNames = new HashSet<QName>(bindings
          .getTagNames(WireParser.CATEGORY_DESCRIPTOR));
      for (QName qName : qNames) {
        bindings.addBinding(new QName(ENVIRONMENT_NS, qName.getLocalPart()),
            bindings.getBinding(qName, WireParser.CATEGORY_DESCRIPTOR),
            WireParser.CATEGORY_DESCRIPTOR);
      }
      qNames = new HashSet<QName>(bindings
          .getTagNames(WireParser.CATEGORY_OPERATION));
      for (QName qName : qNames) {
        bindings.addBinding(new QName(ENVIRONMENT_NS, qName.getLocalPart()),
            bindings.getBinding(qName, WireParser.CATEGORY_OPERATION),
            WireParser.CATEGORY_OPERATION);
      }
      qNames = new HashSet<QName>(bindings
          .getTagNames(WireParser.CATEGORY_INTERCEPTOR));
      for (QName qName : qNames) {
        bindings.addBinding(new QName(ENVIRONMENT_NS, qName.getLocalPart()),
            bindings.getBinding(qName, WireParser.CATEGORY_INTERCEPTOR),
            WireParser.CATEGORY_INTERCEPTOR);
      }
      // Use the same bindings in block and application contexts
      instance.getApplicationWireXmlParser().setBindings(bindings);
      // Add orchestra bindings
      bindings.addBinding(new QName(ENVIRONMENT_NS,
          "hibernate-bpel-persistence-service"),
          new HibernateBpelPersistenceServiceBinding(),
          WireParser.CATEGORY_DESCRIPTOR);
      bindings.addBinding(new QName(ENVIRONMENT_NS, "repository"),
          new ImplementationBinding(), WireParser.CATEGORY_DESCRIPTOR);
      bindings.addBinding(new QName(ENVIRONMENT_NS, "invoker"),
          new ImplementationBinding(), WireParser.CATEGORY_DESCRIPTOR);
      bindings.addBinding(new QName(ENVIRONMENT_NS, "publisher"),
          new ImplementationBinding(), WireParser.CATEGORY_DESCRIPTOR);
    }
    return instance;
  }

  public static EnvironmentFactory parseEnvironmentFactoryFromXmlString(
      String xmlString) {
    Parse parse = new Parse();
    EnvironmentFactory factory = (EnvironmentFactory) getInstance()
        .parseXmlString(xmlString, parse);
    parse.checkProblems("environment");
    return factory;
  }

  public static synchronized EnvironmentFactory parseEnvironmentFactoryFromResource(
      String resource) {
    Parse parse = new Parse();
    EnvironmentFactory factory = (EnvironmentFactory) getInstance()
        .parseResource(resource, null, parse);
    parse.checkProblems("environment");
    return factory;
  }

  public synchronized DocumentBuilderFactory getDocumentBuilderFactory() {
    documentBuilderFactory = newDocumentBuilderFactory();
    documentBuilderFactory.setNamespaceAware(true);
    // documentBuilderFactory.setValidating(true);
    // ignore white space can only be set if parser is validating
    documentBuilderFactory.setIgnoringElementContentWhitespace(true);
    // select xml schema as the schema language (a.o.t. DTD)
    // documentBuilderFactory.setAttribute(
    // "http://java.sun.com/xml/jaxp/properties/schemaLanguage",
    // "http://www.w3.org/2001/XMLSchema");
    // set schema sources
    // URL url = getClassLoader().getResource("environment-orchestra.xsd");

    // documentBuilderFactory.setAttribute(
    // "http://java.sun.com/xml/jaxp/properties/schemaSource", new
    // String[]{url.toExternalForm()});
    return documentBuilderFactory;
  }
}
