/**
 * Bull SAS / OW2 Orchestra
 * Copyright (C) 2007 Bull S.A.S, and individual contributors as indicated
 * by the @authors tag. 
 *
 * Bull, Rue Jean Jaures, B.P.68, 78340, Les Clayes-sous-Bois
 * This library is free software; you can redistribute it and/or modify it under the terms
 * of the GNU Lesser General Public License as published by the Free Software Foundation
 * version 2.1 of the License.
 * This library is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
 * without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU Lesser General Public License for more details.
 * You should have received a copy of the GNU Lesser General Public License along with this
 * program; if not, write to the Free Software Foundation, Inc., 51 Franklin Street, Fifth
 * Floor, Boston, MA  02110-1301, USA.
 **/
package org.ow2.orchestra.execution.element;

import java.io.Serializable;
import java.util.List;

import javax.wsdl.Port;
import javax.wsdl.PortType;
import javax.xml.namespace.QName;

/**
 * @author Goulven Le Jeune, Charles Souillard, Candy Chlad, Stanislas Giraudet
 *         De Boudemange
 */
public class PartnerLink implements Serializable {

  /** serialVersionUID. */
  private static final long serialVersionUID = 1L;

  protected long dbid;

  /** name attribute of this partnerLink. */
  protected String name;

  /**
   * portType QName of the PartnerLinkType associated to myRole of this
   * partnerLink.
   */
  protected QName myRolePortTypeQName;

  /** portType of the PartnerLinkType associated to myRole of this partnerLink. */
  protected PortType myRolePortType;

  /**
   * list of ports associated to the partnerLinkType associated to myRoleRole of
   * this partnerLink.
   */
  protected List<Port> myRolePorts;

  /**
   * portType QName of the PartnerLinkType associated to partnerRole of this
   * partnerLink.
   */
  protected QName partnerRolePortTypeQName;

  /**
   * portType of the PartnerLinkType associated to partnerRole of this
   * partnerLink.
   */
  protected PortType partnerRolePortType;

  /**
   * list of ports associated to the partnerLinkType associated to partnerRole
   * of this partnerLink.
   */
  protected List<Port> partnerRolePorts;

  /** intitializePartnerRole Attribute. */
  protected boolean initializePartnerRole = false;

  public String getName() {
    return name;
  }

  public void setName(String name) {
    this.name = name;
  }

  public PortType getMyRolePortType() {
    return myRolePortType;
  }

  public void setMyRolePortType(PortType myRolePortType) {
    this.myRolePortType = myRolePortType;
  }

  public void setInitializePartnerRole(boolean initializePartnerRole) {
    this.initializePartnerRole = initializePartnerRole;
  }
  
  public QName getMyRolePortTypeQName() {
    return myRolePortTypeQName;
  }

  public void setMyRolePortTypeQName(QName myRolePortTypeQName) {
    this.myRolePortTypeQName = myRolePortTypeQName;
  }

  public PortType getPartnerRolePortType() {
    return partnerRolePortType;
  }

  public void setPartnerRolePortType(PortType partnerRolePortType) {
    this.partnerRolePortType = partnerRolePortType;
  }

  public QName getPartnerRolePortTypeQName() {
    return partnerRolePortTypeQName;
  }

  public void setPartnerRolePortTypeQName(QName partnerRolePortTypeQName) {
    this.partnerRolePortTypeQName = partnerRolePortTypeQName;
  }

  public List<Port> getMyRolePorts() {
    return this.myRolePorts;
  }

  public void setMyRolePorts(List<Port> myRolePorts) {
    this.myRolePorts = myRolePorts;
  }

  public List<Port> getPartnerRolePorts() {
    return this.partnerRolePorts;
  }

  public void setPartnerRolePorts(List<Port> partnerRolePorts) {
    this.partnerRolePorts = partnerRolePorts;
  }
  
  public boolean getInitializePartnerRole() {
    return this.initializePartnerRole;
  }

}
