package org.ow2.orchestra.execution.services.db.hibernate;

import org.ow2.orchestra.env.DefaultEnvXMLGenerator;
import org.ow2.orchestra.execution.services.db.DbRepository;

/**
 * Generates a default environment configuration for running Orchestra.
 * 
 * @author Guillaume Porcher, Charles Souillard
 * 
 */
public class DbEnvXMLGenerator extends DefaultEnvXMLGenerator {

  public DbEnvXMLGenerator() {
    super();

    String hibernateConfigXml = "";
    hibernateConfigXml += "    <hibernate-session-factory table-prefix='NOVA_'>\n";
    hibernateConfigXml += "      <properties resource='hibernate.properties' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.definition.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.execution.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.job.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.queries.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.type.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='hibernate.wire.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.activities.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.elements.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.execution.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.runtime.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.services.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.queries.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.util.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.wsdl.hbm.xml' />\n";
    hibernateConfigXml += "      <mapping resource='bpel.lang.hbm.xml' />\n";
    hibernateConfigXml += "      <cache-configuration resource='pvm.definition.cache.xml' usage='read-write' />\n";
    hibernateConfigXml += "      <cache-configuration resource='bpel.cache.xml' usage='read-write' />\n";
    hibernateConfigXml += "    </hibernate-session-factory>";
    this.setApplicationEntry("hibernate-session-factory", hibernateConfigXml);

    String commandServiceConfigXml = "    <standard-command-service>\n";
    commandServiceConfigXml += "      <retry-interceptor />\n";
    commandServiceConfigXml += "      <environment-interceptor />\n";
    commandServiceConfigXml += "      <transaction-interceptor />\n";
    commandServiceConfigXml += "    </standard-command-service>\n";
    this.setApplicationEntry("standard-command-service", commandServiceConfigXml);
    this.setApplicationEntry("job-executor",
          "    <job-executor threads='1' auto-start='false' />");

    this.setRepositoryType(DbRepository.class);

    this.setBlockEntry("transaction", "    <standard-transaction />");
    this.setBlockEntry("session", "    <hibernate-session />");

    // String hibernateServiceXml = "";
    // hibernateServiceXml += " <object name='" + PersistenceService.NAME
    // + "' class='" + HibernateBpelPersistenceService.class.getName() + "'
    // >\n";
    // hibernateServiceXml += " <constructor>\n";
    // hibernateServiceXml += " <arg><ref object='session' /></arg>\n";
    // hibernateServiceXml += " </constructor>\n";
    // hibernateServiceXml += " </object>";

    // TODO: change name
    this.setBlockEntry("persistence_service",
        "    <hibernate-bpel-persistence-service />");

    this.setBlockEntry("timer_session", "    <timer-session />");
    this.setBlockEntry("job-session", "    <job-session />");
  }

}
